@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '1.12'
-Build = '2'
+Build = '5'
 
 import sys
 import os
@@ -55,17 +55,6 @@ def showQuickMessage(message):
                /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
 
-def checkFile(Path, File):
-    ''' Check if a file exists. '''
-
-    try:
-       f = open(Path + '/' + File, 'r')
-       f.close()
-    except:
-       return False
-    else:
-       return True
-
 class clevenMainWindow(QtGui.QMainWindow): # need fixes
 
     def __init__(self, parent=None):
@@ -96,7 +85,7 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        QtCore.QObject.connect(self.ui.injectionButton, QtCore.SIGNAL('clicked()'), self.executeInjection)
 
        self.showStartupDialog()          ## (Un)comment for pop-up of the start-up dialog at start-up
-       self.showConfigureDriversDialog() ## (Un)comment for pop-up of the configuration dialog at start-up  
+       # self.showConfigureDriversDialog() ## (Un)comment for pop-up of the configuration dialog at start-up  
 
        self.ui.captureButton.setEnabled(False)
        self.ui.injectionButton.setHidden(True)
@@ -130,10 +119,6 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        
        # print driverStateInjection, interfaceStateMonitor
 
-       ##Clean the interface
-       self.ui.scanList.clear()
-       self.ui.textBrowser.clear()
-       
        ##Check first if the correct drivers are loaded and the interface is in monitor mode
        if driverStateInjection == 'False' or interfaceStateMonitor == 'False':
           message ='ERROR: Cannot scan for available networks.\n\nThe drivers or the interface are not to the correct state.\nPlease configure them from the available menu option.'
@@ -145,11 +130,9 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
           showQuickMessage(message) 
           
           os.system('sudo %s/%s getWlanInformation %s %s' % (pathMain, helperScript, pathTemp, duration))
-          message ='Scan for available networks completed!\nChoose WEP or WPA..'
+          message ='Scan for available networks completed!'
           showQuickMessage(message)
 
-       self.ui.textBrowser.append(message)
-
     def displayNetworks(self): #FIXME: read ESSIDs directly and not from the file.
        '''Show available networks in the UI.'''
 
@@ -180,12 +163,12 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        values.sort(key=str.lower)             ##sort them by name.
        # print "ESSIDs sorted:\n", values
 
-       print "BSSIDs to put in the list:\n", values
+       # print "BSSIDs to put in the list:\n", values
        self.ui.scanList.addItems(values)
 
     def displayNetworkInformation(self): #FIXME: read wlan info directly and not from a file.
 
-       global essid, bssid, channel, encryption, essid_clean
+       global essid, bssid, channel, encryption
     
        if self.ui.scanList.currentRow() == -1:
           self.ui.textBrowser.clear()
@@ -193,15 +176,13 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
           return
        self.ui.captureButton.setEnabled(True)
        essid = self.ui.scanList.currentItem().text()
-       essidInfo = os.popen('sudo %s/%s readESSIDinfo %s \"%s\"' % (pathMain, helperScript, pathTemp, essid)).read().split("\n")
-       
-       print essidInfo
+       essidInfo = os.popen('sudo %s/%s readESSIDinfo %s %s' % (pathMain, helperScript, pathTemp, essid)).read().split("\n")
        
        essid = essidInfo[0]
        bssid = essidInfo[1]
        channel = essidInfo[2]
        encryption = essidInfo[3]
-       essid = essid.lstrip(" ").rstrip(" ")
+       essid = essid.strip()
        bssid = bssid.strip()
        channel = channel.strip()
        encryption = encryption.strip()
@@ -210,14 +191,6 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        self.ui.textBrowser.append('Name: ' + essid)
        self.ui.textBrowser.append('MAC: ' + bssid)
        self.ui.textBrowser.append('Ch: ' + channel + ' Security: ' + encryption)
-
-       
-       essid_clean = essid
-       character_list = [' ', '(', ')', '!', '$', '%', '^', '&', '*', '-', '+', '=', '#', '@', ';', ':', '?', '/', '>', '<'] 
-       for i in character_list:
-          essid_clean = essid_clean.replace(i,'_')
-       print 'essid (clean): ', essid_clean   
-       
     def executeCapture(self):
        '''Opens an xterm window that captures the packets.'''
    
@@ -249,13 +222,12 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
 
           self.ui.authenticateButton.setEnabled(False)
           self.ui.injectionButton.setEnabled(False)
-          self.ui.deauthenticateButton.setEnabled(True)
+          # self.ui.deauthenticateButton.setEnabled(True) ##INFO: uncomment when "executeDeauthenticate" is fixed.
           
-       # print "capture options: ", channel, bssid, pathTemp, encryption, essid, essid_clean
-       # os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s \"%s\" " &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid))
-       os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s \"%s\" " &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid_clean))
+       # print "capture options: ", channel, bssid, pathTemp, encryption, essid
+       os.system('osso-xterm -e "sudo %s/%s capture %s %s %s %s %s" &' % (pathMain, helperScript, channel, bssid, pathTemp, encryption, essid))
       
-    def executeDeauthenticate(self): #FIXME:: the essid should be the connected client's mac; atm ignoring essid and just broadcasting. 
+    def executeDeauthenticate(self): #FIXME:: the essid should be the connected client's mac
        '''Opens an xterm window that sends deauthentication packets.'''
        
        # print "deauthenticate options: ", bssid, essid
@@ -264,7 +236,7 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
     def executeAuthenticate(self):
        '''Opens an xterm window that sends authentication packets.'''
        
-       # print "authenticate options: ", bssid, myMAC, essid
+       # print "authenticate options: ", essid, bssid, myMAC
        os.system('osso-xterm -e "sudo %s/%s authenticate %s %s \"%s\" " &' % (pathMain, helperScript, bssid, myMAC, essid))
 
     def executeInjection(self):
@@ -295,7 +267,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        QtCore.QObject.connect(self.ui.ANY, QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
        QtCore.QObject.connect(self.ui.ASK, QtCore.SIGNAL('clicked()'), self.setConnectionBehaviour)
        
-       ##Get and populate the UI with the curent info 
+       ##Get and populate the UI with the current info 
        self.getKernelVersion()
        self.getDriversState()
        self.getInterfaceState()
@@ -316,8 +288,10 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
           pass
        elif kernelVersion == '2.6.28.10-power48':
           pass
+       elif kernelVersion == '2.6.28.10-power49':
+          pass
        else: 
-          message = 'WARNING: The system did not find a known compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
+          message = 'WARNING: The system did not find a compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
           showMessage(message)
     
     def getDriversState(self):
@@ -399,10 +373,10 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        '''Get the MAC address defined on the device'''
 
        if self.ui.enableMonitor.isEnabled():
-          ##interface is in Managed mode
+          #interface is in Managed mode
           macList = os.popen('sudo %s/%s getMACmanaged' %(pathMain, helperScript)).read()
        else:
-          ##interface is in Monitor mode 
+          #interface is in Monitor mode 
           macList = os.popen('sudo %s/%s getMACmonitor' %(pathMain, helperScript)).read()
        
        myMAC = macList[0:17]
@@ -447,7 +421,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
     def setConnectionBehaviour(self):
        '''Set new data connection behaviour.'''
 
-       ##Available options: [WLAN_INFRA], [GPRS], [*] <=='any', [] <=='ask'
+       ## Available options: [WLAN_INFRA], [GPRS], [*] <=='any', [] <=='ask'
        if self.ui.ASK.isChecked():
            String = ''
        elif self.ui.WLAN.isChecked():
@@ -457,7 +431,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        elif self.ui.ANY.isChecked():
            String = '*'
           
-       ##Set user requested value for the "Connect automatically" option 
+       ## Set requested setting for "Connect automatically" 
        os.system('gconftool-2 -s --type list --list-type string /system/osso/connectivity/network_type/auto_connect [%s]' % String)
 
 class clevenSelectDictionary(QtGui.QDialog): # Complete
@@ -496,7 +470,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        QtCore.QObject.connect(self.ui.actionEnableDeleteOptions, QtCore.SIGNAL('triggered()'), self.enableDeleteOptions)
        QtCore.QObject.connect(self.ui.actionDisableDeleteOptions, QtCore.SIGNAL('triggered()'), self.disableDeleteOptions)
        
-       ##Decryption
+       # Decryption
        QtCore.QObject.connect(self.ui.decryptButton, QtCore.SIGNAL('clicked()'), self.decryptORdeleteCapturedFiles)
        QtCore.QObject.connect(self.ui.dictionaryButton, QtCore.SIGNAL('clicked()'), self.showSelectDictionaryDialog)
        QtCore.QObject.connect(self.ui.capturedList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableDecryptionButtons)
@@ -534,19 +508,13 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        
        global deleteModeOn
        deleteModeOn = 'True'
-
-       self.setWindowTitle('Deletion')
        
        self.ui.decryptButton.setEnabled(False)
        self.ui.decryptButton.setText('Delete')       
        self.ui.selectCommonRadio.setEnabled(False)
-
        self.ui.actionEnableDeleteOptions.setEnabled(False)
        self.ui.actionDisableDeleteOptions.setEnabled(True)
-       
-       ##Hide the dictionary selection buttons 
-       self.ui.dictionaryButton.setHidden(True)
-       self.ui.dictionaryLine.setHidden(True)
+       self.setWindowTitle('Deletion')
        
     def disableDeleteOptions(self):
        '''Disable in the UI the Delete buttons'''
@@ -579,7 +547,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        self.ui.decryptButton.setEnabled(False)
        
        clist = os.listdir(pathTemp + '/' + folderCapturedData + '/' + encryption)
-       clist_clean = [line for line in clist if (('.cap' in line) or ('ivs' in line))]
+       clist_clean = [line for line in clist if (('.cap' in line) or ('.ivs' in line))]
        clist_clean.sort(key=str.lower)
        self.ui.capturedList.addItems(clist_clean)
 
@@ -595,10 +563,10 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        ##Decrypt files
        if deleteModeOn == 'False':
           if self.ui.selectCommonRadio.isChecked():
-             name = self.capfile.strip().partition('-') #not ideal since name with "-" will be split earlier
+             name = self.capfile.strip().rpartition('-')
              name = name[0]
-             suffix = self.capfile.strip().partition('.')
-             suffix = suffix[1]
+             suffix = self.capfile.strip().rpartition('.')
+             suffix = suffix[2]
              if suffix == 'ivs':
                 cap = name+'*.ivs'
              else:
@@ -629,11 +597,10 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
              encryption = "WPA"
              
           if self.ui.selectCommonRadio.isChecked():
-             ##FIXME: add a check if the name has also a '-'
-             name = self.capfile.strip().partition('-')
+             name = self.capfile.strip().rpartition('-')
              cap = name[0]
           else:
-             cap = self.capfile.strip().replace('.cap','').replace('.ivs','')
+             cap = self.capfile.strip().replace('.cap','')
           print "delete cap: ", cap
 
           os.system('sudo %s/%s deleteCaptured %s %s %s' % (pathMain, helperScript, pathTemp, encryption, cap))
@@ -694,7 +661,7 @@ class clevenAbout(QtGui.QMainWindow): # Complete
        aboutScrollArea = QScrollArea(self)
        aboutScrollArea.setWidgetResizable(True)
        awidget = QWidget(aboutScrollArea)
-       # awidget.setMinimumSize(470,1480)
+       #awidget.setMinimumSize(470,1480)
        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        try:
@@ -706,28 +673,34 @@ class clevenAbout(QtGui.QMainWindow): # Complete
        aboutLayout = QVBoxLayout(awidget)
        
        aboutIcon = QLabel()
-       aboutIcon.setPixmap( QIcon.fromTheme('cleven').pixmap(64,64) )
-       aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+       aboutIcon.setPixmap( QIcon.fromTheme('cleven').pixmap(128,128) )
        aboutIcon.resize(128,128)
+       aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
        aboutLayout.addWidget(aboutIcon)
        
-       aboutLabel = QLabel('''<center><b>Cleven</b> version: %s 
-       <br><br><b>Cleven is a user interface to the aircrack-ng console application.</b> 
-       <br><br>Licenced under GPLv2 
+       aboutLabel = QLabel('''<center><b>Cleven</b><br>version: %s 
+       <br><br><b>Cleven is a user interface to the AirCrack-NG console application.</b> 
+       <br><br>Licenced under GPLv2
        <br>by <b>Christos Zamantzas</b> (Saturn) 
-       <br><br>It provides the ability to easily configure the injection drivers, scan for surrounding stations, and, using injection and authentication or deauthentication, capture the Identification Vector keys.  In addition, it provides interfaces to decrypt the captured files and manage the successful attacks.  
-       <br><br><b>DISCLAIMER:</b> This program is intended for learning purposes only. I do not condone hacking and would not be held responsible for your actions. Only you would face legal consequences if you used this application for illegal activities.  Additional information on the usage, settings and implications can be found in the wiki pages (see buttons in the end).
-       <br><br><b>THANKS TO:
-       <br></b> <b>David Gnedt</b> (lxp) for the development of the bleeding-edge wlan drivers. You can support his work by donating. See here for more info: http://david.gnedt.eu/blog/wl1251/
-       <br><b>Benoit HERVIER</b> at http://khertan.net/ for the code used in this about window. </center>''' % Version)
+       <br><br>It provides the ability to easily configure the injection drivers, scan for surrounding stations, and by using injection and authentication or deauthentication, capture Identification Vector keys. 
+       <br><br>In addition, it provides interfaces to decrypt the captured files and manage the keys from successful attacks. 
+       <br><br><b>DISCLAIMER:</b> 
+       <br>This program is intended for learning purposes only. I do not condone hacking and would not be held responsible for your actions. Only you would face legal consequences if you used this script for illegal activities. 
+       <br><br>Additional information on the usage, settings and implications can be found in the wiki pages (see buttons in the end). 
+       <br><br><b>THANKS TO:</b> 
+       <br><br><b>David Gnedt</b> (lxp) for the development of the bleeding-edge wlan drivers. You can support his work by sending him your donations. See for more info: http://david.gnedt.eu/blog/wl1251/ 
+       <br><br><b>Benoit HERVIER</b> at http://khertan.net/ for the code used in this about window. 
+       <br></center>''' % Version)
+       
+       aboutLabel.setWordWrap(True)
+       aboutLabel.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
        
-       aboutLabel.setWordWrap(True)       
        aboutLayout.addWidget(aboutLabel)
-       
        self.wikiButton = QPushButton('Cleven Wiki')
        self.wikiButton.clicked.connect(self.openWikiPage)
        self.issuesButton = QPushButton('Issue Tracker')
        self.issuesButton.clicked.connect(self.openIssueTracker)
+       
        awidget2 = QWidget()
        buttonLayout = QHBoxLayout(awidget2)        
        buttonLayout.addWidget(self.wikiButton)
@@ -761,10 +734,10 @@ class clevenStartup(QtGui.QDialog): # Complete
 
     def timerEvent(self, event):
 
-       if self.step >= 100 or self.ui.skipIntroRadioButton.isChecked():
+       if self.step >= 100:
           self.timer.stop()
           self.close()
-       self.step = self.step + 1
+       self.step = self.step + 2
        self.ui.progressBarStart.setValue(self.step)
     
 class clevenMain(): # Complete
